@@ -1,12 +1,12 @@
 package org.ovirt.engine.core.bll;
 
-import static org.junit.Assert.assertEquals;
+import static org.junit.jupiter.api.Assertions.assertEquals;
 import static org.mockito.Mockito.when;
 
 import java.util.Collections;
 import java.util.List;
 
-import org.junit.Test;
+import org.junit.jupiter.api.Test;
 import org.mockito.Mock;
 import org.ovirt.engine.core.common.businessentities.VDS;
 import org.ovirt.engine.core.common.queries.GetHostsForStorageOperationParameters;
@@ -36,6 +36,6 @@ public class GetHostsForStorageOperationQueryTest extends AbstractQueryTest<GetH
         getQuery().executeQueryCommand();
 
         // Check the result
-        assertEquals("Wrong Vds returned", result, getQuery().getQueryReturnValue().getReturnValue());
+        assertEquals(result, getQuery().getQueryReturnValue().getReturnValue(), "Wrong Vds returned");
     }
 }
