@@ -8,6 +8,7 @@ import java.util.TimeZone;
 
 import org.apache.commons.lang.StringUtils;
 import org.ovirt.engine.core.common.businessentities.storage.DiskImage;
+import org.ovirt.engine.core.common.businessentities.storage.LunDisk;
 import org.ovirt.engine.core.compat.Guid;
 import org.ovirt.engine.core.utils.ovf.xml.XmlDocument;
 import org.ovirt.engine.core.utils.ovf.xml.XmlNode;
@@ -66,6 +67,20 @@ public class OvfParser {
         return retVal;
     }
 
+    /**
+     * lunDisk is: /dev/mapper/[lun id]
+     *
+     * @param lun
+     *            - The lun disk which will be used to create the mapper string.
+     * @return - Represented guid of the lun mapper.
+     */
+    public static String createLunFile(LunDisk lun) {
+        if (lun.getId() != null) {
+            return lun.getId().toString();
+        }
+        return Guid.Empty.toString();
+    }
+
     public static Guid getImageGroupIdFromImageFile(String imageFile) {
         if (!StringUtils.isBlank(imageFile)) {
             return Guid.createGuidFromStringDefaultEmpty(imageFile.split("[/]", -1)[0]);
@@ -88,7 +103,7 @@ public class OvfParser {
      *
      * @return the date or null if parse failed
      */
-    public static Date utcDateStringToLocaDate(String str) {
+    public static Date utcDateStringToLocalDate(String str) {
         if (StringUtils.isBlank(str)) {
             return null;
         }
