@@ -15,6 +15,7 @@ import org.ovirt.engine.core.common.businessentities.BiosType;
 import org.ovirt.engine.core.common.businessentities.Cluster;
 import org.ovirt.engine.core.common.businessentities.OriginType;
 import org.ovirt.engine.core.common.businessentities.VM;
+import org.ovirt.engine.core.common.businessentities.VMStatus;
 import org.ovirt.engine.core.common.businessentities.VmDevice;
 import org.ovirt.engine.core.common.businessentities.VmDynamic;
 import org.ovirt.engine.core.common.businessentities.VmStatic;
@@ -75,6 +76,8 @@ public class VmManager {
      */
     private int vmMemoryWithOverheadInMB;
 
+    private VMStatus lastStatusBeforeMigration;
+
     @Inject
     private VmDeviceDao vmDeviceDao;
     @Inject
@@ -326,4 +329,12 @@ public class VmManager {
     public void resetExternalDataStatus() {
         externalDataStatus = new ExternalDataStatus();
     }
+
+    public VMStatus getLastStatusBeforeMigration() {
+        return lastStatusBeforeMigration;
+    }
+
+    public void setLastStatusBeforeMigration(VMStatus lastStatusBeforeMigration) {
+        this.lastStatusBeforeMigration = lastStatusBeforeMigration;
+    }
 }
